pub enum IoHandles {
RawHandles(RawHandles),
PtySocket(Socket),
// some variants omitted
}Variants
RawHandles(RawHandles)
Raw handles are provided to the program.
PtySocket(Socket)
A zircon socket is used as data source and the data is forwarded to the program via a PTY device. Both stderr and stdout end up in the same socket.
Implementations