pub enum LauncherRequest {
Launch {
payload: LaunchOptions,
responder: LauncherLaunchResponder,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: LauncherControlHandle,
method_type: MethodType,
},
}Variants
Launch
Launches a process providing it the namespace available to the developer console.
Returns when the launched process exits, informing its return code.
#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

control_handle: LauncherControlHandle
method_type: MethodTypeImplementations
Sourceimpl LauncherRequest
impl LauncherRequest
pub fn into_launch(self) -> Option<(LaunchOptions, LauncherLaunchResponder)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL