pub enum Program {
DefaultShell(Empty),
FromPackage(PackageProgram),
// some variants omitted
}Variants
DefaultShell(Empty)
The default developer shell is launched.
The default shell is controlled by product configuration. Thus, when selecting this program the server automatically fills:
- environment PATH variable.
- arguments for interactive vs not interactive sessions based on
arguments given to
LaunchOptions.
FromPackage(PackageProgram)
The provided program from some package is launched.
When from_package is used the provided package is automatically
added to the namespace under /pkg.
Implementations