pub struct LaunchOptions {
pub name: Option<String>,
pub args: Option<Vec<String>>,
pub program: Option<Program>,
pub io_handles: Option<IoHandles>,
pub env: Option<Vec<String>>,
pub namespace_entries: Option<Vec<NameInfo>>,
pub stopper: Option<EventPair>,
pub directories_fixup: Option<bool>,
/* private fields */
}Expand description
Options given to [Launcher.Launch].
Fields
name: Option<String>The launched process name.
Generated automatically if absent.
args: Option<Vec<String>>Additional arguments to pass to the launched process.
The server computes argv0 automatically from program.
Interpreted as empty vector if absent.
program: Option<Program>The program to run.
Interpreted as Program.default_shell if absent.
io_handles: Option<IoHandles>The standard input/output handles given to the program.
No standard IO handles are given if absent.
env: Option<Vec<String>>Environment variables to set for the launched process.
Interpreted as empty vector if absent.
namespace_entries: Option<Vec<NameInfo>>Extra namespace entries to give to the launched process.
Entries that collide with the default entries provided by the developer console override the defaults.
All namespace entry paths MUST start with a /,
INVALID_NAMESPACE_PATH is returned otherwise.
Interpreted as empty vector if absent.
stopper: Option<EventPair>An event pair that must be kept alive for the created process to be maintained.
Optional. If provided, the container job for the launched process is
destroyed when the peer handle for stopper is closed.
directories_fixup: Option<bool>Enables fixing up the launch namespace for the conventional shell namespace.
When using the /toolbox namespace for launching programs, it may be
necessary to organize the directories given to toolbox so that they look
like a “standardized” directory layout. This is a built-in feature that
allows the server to provide this fix up which consists of walking
/directories in the namespace and applying the following renaming
rules:
/directories/root-ssl-certificates=>/config/ssl./directories/build-info=>/config/build_info./directories/[any]=>/[any].
Interpreted as false if absent.