pub struct RawHandles {
pub stdin: Option<NullableHandle>,
pub stdout: Option<NullableHandle>,
pub stderr: Option<NullableHandle>,
}Fields
stdin: Option<NullableHandle>stdout: Option<NullableHandle>stderr: Option<NullableHandle>Trait Implementations
Sourceimpl Debug for RawHandles
impl Debug for RawHandles
Sourceimpl Decode<RawHandles, DefaultFuchsiaResourceDialect> for RawHandles
impl Decode<RawHandles, DefaultFuchsiaResourceDialect> for RawHandles
Sourceimpl Encode<RawHandles, DefaultFuchsiaResourceDialect> for &mut RawHandles
impl Encode<RawHandles, DefaultFuchsiaResourceDialect> for &mut RawHandles
Sourceimpl<T0: Encode<Optional<HandleType<NullableHandle, { _ }, 2147483648>>, DefaultFuchsiaResourceDialect>, T1: Encode<Optional<HandleType<NullableHandle, { _ }, 2147483648>>, DefaultFuchsiaResourceDialect>, T2: Encode<Optional<HandleType<NullableHandle, { _ }, 2147483648>>, DefaultFuchsiaResourceDialect>> Encode<RawHandles, DefaultFuchsiaResourceDialect> for (T0, T1, T2)
impl<T0: Encode<Optional<HandleType<NullableHandle, { _ }, 2147483648>>, DefaultFuchsiaResourceDialect>, T1: Encode<Optional<HandleType<NullableHandle, { _ }, 2147483648>>, DefaultFuchsiaResourceDialect>, T2: Encode<Optional<HandleType<NullableHandle, { _ }, 2147483648>>, DefaultFuchsiaResourceDialect>> Encode<RawHandles, DefaultFuchsiaResourceDialect> for (T0, T1, T2)
Sourceimpl Hash for RawHandles
impl Hash for RawHandles
Sourceimpl Ord for RawHandles
impl Ord for RawHandles
Sourcefn cmp(&self, other: &RawHandles) -> Ordering
fn cmp(&self, other: &RawHandles) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for RawHandles
impl PartialEq for RawHandles
Sourceimpl PartialOrd for RawHandles
impl PartialOrd for RawHandles
Sourceimpl ResourceTypeMarker for RawHandles
impl ResourceTypeMarker for RawHandles
Sourcetype Borrowed<'a> = &'a mut RawHandles
type Borrowed<'a> = &'a mut RawHandles
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).Sourceimpl TypeMarker for RawHandles
impl TypeMarker for RawHandles
Sourcetype Owned = RawHandles
type Owned = RawHandles
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.impl Eq for RawHandles
impl Standalone<DefaultFuchsiaResourceDialect> for RawHandles
impl StructuralPartialEq for RawHandles